/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/trunk/backends/platform/iphone/osys_main.cpp $
 * $Id: osys_main.cpp 44793 2009-10-08 19:41:38Z fingolfin $
 *
 */

#include <unistd.h>
#include <pthread.h>
#include <semaphore.h>
#include <sys/time.h>

#include "common/scummsys.h"
#include "common/util.h"
#include "common/rect.h"
#include "common/file.h"
#include "common/fs.h"

#include "base/main.h"

#include "backends/saves/default/default-saves.h"
#include "backends/timer/default/default-timer.h"
#include "sound/mixer.h"
#include "sound/mixer_intern.h"

#include "osys_main.h"
#import <engines/engine.h>
#import <engines/igob/gob.h>
#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>
#import "switchViewController.h"
#import "Gob1MenuViewController.h"
#import "iPhoneViewController.h"

//////////////////
//---GAME PARAMS
//LVL (GENERAL)
const char* niveau = " ";
bool bLoadingLevel = false;
bool bLvLLoaded = true;
bool bGoHotspot = false;
bool bPauseActive = false;
bool bHintMenuActive = false;
int idLvLCourant = -1;
int idLvLHigh = -1;
int cptSound = 0;
//LVL (SIMULATION)
bool bSimulation = false;
bool bLvLOneLoaded = true; 
bool bSimulCode = false;
int idLvLToLoad = 7;
int etat = -1;
//GAME (GENERAL)
bool bGobPicker = false;
bool bPopup = false;
bool bGameOverOn = false;
bool bMenuIngame = false;
bool bMenuGob1 = true;
bool bFromMenuIngame = false;
bool bLoadMenu = false;
bool bAnimBeginning = true;
bool iPhoneViewCall = false;
//SOUND
bool bSoundMusicActive = true;
bool bEndOpeningTheme = false;
bool bSetSounds = true;
int idSoundMusic = 192;
int idSoundSFX = 192;
// CD Audio
extern AVAudioPlayer* audioPlayer;
extern AVAudioPlayer* menuPlayer;
//VM
sem_t* sem;
bool bLoopVM = false;
//---END
////////////////

const OSystem::GraphicsMode OSystem_IPHONE::s_supportedGraphicsModes[] = 
{
	{0, 0, 0}
};

AQCallbackStruct OSystem_IPHONE::s_AudioQueue;
SoundProc OSystem_IPHONE::s_soundCallback = NULL;
void *OSystem_IPHONE::s_soundParam = NULL;

OSystem_IPHONE::OSystem_IPHONE() :
	_savefile(NULL), _mixer(NULL), _timer(NULL), _offscreen(NULL),
	_overlayVisible(false), _overlayBuffer(NULL), _fullscreen(NULL),
	_mouseHeight(0), _mouseWidth(0), _mouseBuf(NULL), _lastMouseTap(0),
	_secondaryTapped(false), _lastSecondaryTap(0), _screenOrientation(kScreenOrientationFlippedLandscape),
	_needEventRestPeriod(false), _touchpadModeEnabled(true),
	_gestureStartX(-1), _gestureStartY(-1), _fullScreenIsDirty(false), _fullScreenOverlayIsDirty(false),
	_mouseDirty(false), _timeSuspended(0), _lastDragPosX(-1), _lastDragPosY(-1), _screenChangeCount(0)

{
	_queuedInputEvent.type = (Common::EventType)0;
	_lastDrawnMouseRect = Common::Rect(0, 0, 0, 0);

	_fsFactory = new POSIXFilesystemFactory();
	
	//SIMULATION
	//etat = -1;
	cptEsc = 0;
	bLoop = -1;
	bLoop2 = -1;
	bTempo = -1;
	bPause = -1;
	bGo = -1;
	bAction = -1;
	cpt = 0;
	bCptSimul = 0;
	bLeftClick = false;
	bRightClick = false;
	bRightLeftClick = false;	
	
	sem = sem_open( "mySem", O_CREAT, 0777, 0 );
}

OSystem_IPHONE::~OSystem_IPHONE() {
	AudioQueueDispose(s_AudioQueue.queue, true);

	delete _fsFactory;
	delete _savefile;
	delete _mixer;
	delete _timer;
	delete _offscreen;
	delete _fullscreen;
}

int OSystem_IPHONE::timerHandler(int t)
{
	DefaultTimerManager *tm = (DefaultTimerManager *)g_system->getTimerManager();
	tm->handler();
	return t;
}

void OSystem_IPHONE::initBackend()
{
	_savefile = new DefaultSaveFileManager(iPhone_getDocumentsDir());

	_timer = new DefaultTimerManager();

	gettimeofday(&_startTime, NULL);

	setupMixer();

	setTimerCallback(&OSystem_IPHONE::timerHandler, 10);

	OSystem::initBackend();
}

bool OSystem_IPHONE::hasFeature(Feature f) 
{
	return false;
}

void OSystem_IPHONE::setFeatureState(Feature f, bool enable)
{
	
}

bool OSystem_IPHONE::getFeatureState(Feature f)
{
	return false;
}

void OSystem_IPHONE::suspendLoop()
{
	bool done = false;
	int eventType;
	float xUnit, yUnit;
	uint32 startTime = getMillis();

	stopSoundsystem();

	while (!done)
	{
		if (iPhone_fetchEvent(&eventType, &xUnit, &yUnit))
			if ((InputEvent)eventType == kInputApplicationResumed)
				done = true;
		usleep(100000);
	}
	startSoundsystem();

	_timeSuspended += getMillis() - startTime;
}

uint32 OSystem_IPHONE::getMillis() 
{
	//printf("getMillis()\n");

	struct timeval currentTime;
	gettimeofday(&currentTime, NULL);
	return (uint32)(((currentTime.tv_sec - _startTime.tv_sec) * 1000) + ((currentTime.tv_usec - _startTime.tv_usec) / 1000)) - _timeSuspended;
}

void OSystem_IPHONE::delayMillis(uint msecs) 
{
	//printf("delayMillis(%d)\n", msecs);
	usleep(msecs * 1000);
}

OSystem::MutexRef OSystem_IPHONE::createMutex(void) 
{
	pthread_mutexattr_t attr;
	pthread_mutexattr_init(&attr);
	pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);

	pthread_mutex_t *mutex = (pthread_mutex_t *) malloc(sizeof(pthread_mutex_t));
	if (pthread_mutex_init(mutex, &attr) != 0)
	{
		//printf("pthread_mutex_init() failed!\n");
		free(mutex);
		return NULL;
	}

	return (MutexRef)mutex;
}

void OSystem_IPHONE::lockMutex(MutexRef mutex) 
{
	if (pthread_mutex_lock((pthread_mutex_t *) mutex) != 0) 
	{
		;//printf("pthread_mutex_lock() failed!\n");
	}
}

void OSystem_IPHONE::unlockMutex(MutexRef mutex) 
{
	if (pthread_mutex_unlock((pthread_mutex_t *) mutex) != 0)
	{
		;//printf("pthread_mutex_unlock() failed!\n");
	}
}

void OSystem_IPHONE::deleteMutex(MutexRef mutex) {
	if (pthread_mutex_destroy((pthread_mutex_t *) mutex) != 0) 
	{
		;//printf("pthread_mutex_destroy() failed!\n");
	}
	else 
	{
		free(mutex);
	}
}


void OSystem_IPHONE::setTimerCallback(TimerProc callback, int interval) 
{
	//printf("setTimerCallback()\n");

	if (callback != NULL)
	{
		_timerCallbackTimer = interval;
		_timerCallbackNext = getMillis() + interval;
		_timerCallback = callback;
	} 
	else
		_timerCallback = NULL;
}

void OSystem_IPHONE::quit() 
{
	
}

void OSystem_IPHONE::getTimeAndDate(TimeDate &td) const 
{
	time_t curTime = time(0);
	struct tm t = *localtime(&curTime);
	td.tm_sec = t.tm_sec;
	td.tm_min = t.tm_min;
	td.tm_hour = t.tm_hour;
	td.tm_mday = t.tm_mday;
	td.tm_mon = t.tm_mon;
	td.tm_year = t.tm_year;
}

Common::SaveFileManager *OSystem_IPHONE::getSavefileManager()
{
	assert(_savefile);
	return _savefile;
}

Audio::Mixer *OSystem_IPHONE::getMixer() 
{
	assert(_mixer);
	return _mixer;
}

Common::TimerManager *OSystem_IPHONE::getTimerManager()
{
	assert(_timer);
	return _timer;
}

OSystem *OSystem_IPHONE_create() 
{
	return new OSystem_IPHONE();
}

void initScumm(int argc, char** argv)
{
	do 
	{
		chdir( iPhone_getDocumentsDir() );
		g_system = OSystem_IPHONE_create();
		assert(g_system);

		if( bLoopVM )
		{
			// Event manager
			DefaultEventManager* emg = (DefaultEventManager*)(g_system->getEventManager());
			emg->_shouldQuit = false;
		}
		
		// Ugly hack to launch directly gob1
		int myArgc = argc+2;
		char** myArgv = (char**)malloc((myArgc)*sizeof(char*));
		for (int i = 0 ; i < argc ; i++)
		{
			myArgv[i] = (char*)malloc((strlen(argv[i])+1)*sizeof(char));
			strcpy(myArgv[i],argv[i]);
		}
		myArgv[argc] = (char*)malloc(1024);
		strcpy(myArgv[argc],"-p");
		strcat(myArgv[argc],iPhone_getBundleDir());
		myArgv[argc+1] = (char*)malloc(256);
		strcpy(myArgv[argc+1],"gob1"); 
		
		// Invoke the actual ScummVM main entry point:
		scummvm_main(myArgc, myArgv);
		g_system->quit();       // TODO: Consider removing / replacing this!
		
		//on redemarre la VM
		bLoopVM = true;
		[audioPlayer stop]; //on stoppe le son
				
		delete g_system;
	}
	while(1);
	
	[audioPlayer release];
	audioPlayer = nil;
}

Common::SeekableReadStream *OSystem_IPHONE::createConfigReadStream()
{
	char buf[256];
	strncpy(buf, iPhone_getDocumentsDir(), 256);
	strncat(buf, "/Preferences", 256 - strlen(buf) );
	Common::FSNode file(buf);
	return file.createReadStream();
}

Common::WriteStream *OSystem_IPHONE::createConfigWriteStream()
{
	char buf[256];
	strncpy(buf, iPhone_getDocumentsDir(), 256);
	strncat(buf, "/Preferences", 256 - strlen(buf) );
	Common::FSNode file(buf);
	return file.createWriteStream();
}

void OSystem_IPHONE::addSysArchivesToSearchSet(Common::SearchSet &s, int priority)
{
	// Get URL of the Resource directory of the .app bundle
	CFURLRef fileUrl = CFBundleCopyResourcesDirectoryURL(CFBundleGetMainBundle());
	if (fileUrl) 
	{
		// Try to convert the URL to an absolute path
		UInt8 buf[MAXPATHLEN];
		if (CFURLGetFileSystemRepresentation(fileUrl, true, buf, sizeof(buf))) 
		{
			// Success: Add it to the search path
			Common::String bundlePath((const char *)buf);
			s.add("__OSX_BUNDLE__", new Common::FSDirectory(bundlePath), priority);
		}
		CFRelease(fileUrl);
	}
}


//CD AUDIO
/**
 * Start audio CD playback.
 * @param track			the track to play.
 * @param num_loops		how often playback should be repeated (-1 = infinitely often).
 * @param start_frame	the frame at which playback should start (75 frames = 1 second).
 * @param duration		the number of frames to play.
 */
int musicCur;
void OSystem_IPHONE::playCD(int track, int num_loops, int start_frame, int duration) 
{
	// We multiply by 40 / 3 = 1000 / 75 to convert frames to milliseconds
	// stream = AudioStream::openStreamFile(trackName[i], startFrame * 40 / 3, duration * 40 / 3, (numLoops < 1) ? numLoops + 1 : numLoops);
	
	if( !bSimulation  && !bMenuGob1 )
	{				
		if( //animation début niveau 5
		    ( start_frame == 63454  && duration == 1474 ) ||     //en
			( start_frame == 61618  && duration == 1797 ) ||     //fr 
		    ( start_frame == 68542  && duration == 1235 ) ||     //de
			( start_frame == 64967  && duration == 1834 ) ||     //it 
			( start_frame == 66840  && duration == 1663 ) ||     //es 
		    //animation début niveau 8
			( start_frame == 71742  && duration == 1976 ) ||     //en
		    ( start_frame == 69816  && duration == 1887 ) ||     //fr
		    ( start_frame == 77705  && duration == 1950 ) ||     //de
			( start_frame == 73757  && duration == 1951 ) ||     //it 
			( start_frame == 75747  && duration == 1919 ) ||     //es  
		    //animation début niveau 13
			( start_frame == 81756  && duration == 1879 ) ||     //en
			( start_frame == 79694  && duration == 2023 ) ||     //fr
		    ( start_frame == 87614  && duration == 1945 ) ||     //de
			( start_frame == 83674  && duration == 1913 ) ||     //it 
			( start_frame == 85626  && duration == 1949 ) ||     //es 
		    //animation début niveau 16
			( start_frame == 91277  && duration == 1574 ) ||     //en
		    ( start_frame == 89598  && duration == 1640 ) ||     //fr
		    ( start_frame == 96134  && duration == 1515 ) ||     //de
			( start_frame == 92890  && duration == 1487 ) ||     //it
			( start_frame == 94416  && duration == 1679 ) ||     //es   
		    //animation début niveau 19
			( start_frame == 99224  && duration == 1348 ) ||     //en
			( start_frame == 97688  && duration == 1497 ) ||     //fr
			( start_frame == 103678 && duration == 1465 ) ||     //de 
			( start_frame == 100611 && duration == 1440 ) ||     //it
			( start_frame == 102090 && duration == 1549 ) ||     //es    
		    //animation début niveau 22
		    ( start_frame == 107120 && duration == 1823 ) ||     //en
			( start_frame == 113168 && duration == 2030 ) ||     //de 
			( start_frame == 108982 && duration == 2045 ) ||     //it 
			( start_frame == 111066 && duration == 2063 ) ||     //es 
		    ( start_frame == 105182 && duration == 1899 )        //fr 
		   )      
		{
			[[NSNotificationCenter defaultCenter] postNotificationName:@"hideButtonsNotif" object:nil];	
			[[NSNotificationCenter defaultCenter] postNotificationName:@"loadingScreenOff" object:nil];			
		}
	
		//END GAME
		if( start_frame == 138096 && duration == 9868 && idLvLCourant == 22 && !bPopup )
		{
			[[NSNotificationCenter defaultCenter] postNotificationName:@"endGameNotif" object:nil];
			idLvLCourant = -2;
		}
		else if( start_frame == 51813 && duration == 9766 && idLvLCourant == -2 )
		{
			if( bSoundMusicActive )
				[audioPlayer stop];
			[[NSNotificationCenter defaultCenter] postNotificationName:@"endAnimEndGameNotif" object:nil];
			bMenuGob1 = true;
		}
		//---END
		
		if( idLvLCourant != -2 )
		{
			//skip pour animation BEGINNING
			if( start_frame == 51813 && duration == 9766 )
			{	
				idLvLCourant = 1;
				bAnimBeginning = true;
			}
			else if( start_frame == 138096 && duration == 9868 )
			{
				bEndOpeningTheme = true;
				bAnimBeginning = true;
			}
			//---END
		}
		
		//Si on a la musique du jeu d'active
		if( bSoundMusicActive && !bMenuGob1 )
		{
			if( audioPlayer != nil )
			{
				[menuPlayer stop];
				[audioPlayer stop];
				audioPlayer.volume = (float)((float)idSoundMusic / 256.0f);
				audioPlayer.numberOfLoops = num_loops;
				audioPlayer.currentTime = start_frame * 40 / 3 / 1000.0;
				
				if( 
				    ( start_frame == 63454  && duration == 1474)  || //en
				    ( start_frame == 68542  && duration == 1235 ) || //de
					( start_frame == 64967  && duration == 1834 ) || //it
					( start_frame == 66840  && duration == 1663 ) || //es 
				    ( start_frame == 61618  && duration == 1797 )    //fr
				  )
					[[NSNotificationCenter defaultCenter] postNotificationName:@"hackSoundLevel5Notif" object:nil];
				
				musicCur = audioPlayer.currentTime;
				[audioPlayer play];
			}
		}
		else if( bSoundMusicActive && bMenuGob1 )
		{
			[audioPlayer stop];
		}
		//---END
		
		//debut du niveau - début musique = donc affichage des boutons
		if( !( ( start_frame == 51813  && duration == 9766 ) ||
			   ( start_frame == 138096 && duration == 9868 ) ||
			   //animation début niveau 5
			   ( start_frame == 61618  && duration == 1797 ) ||     //fr
			   ( start_frame == 63454  && duration == 1474 ) ||     //en
			   ( start_frame == 68542  && duration == 1235 ) ||     //de
			   ( start_frame == 64967  && duration == 1834 ) ||     //it
			   ( start_frame == 66840  && duration == 1663 ) ||     //es 
			   //animation début niveau 8
			   ( start_frame == 69816  && duration == 1887 ) ||     //fr
			   ( start_frame == 71742  && duration == 1976 ) ||     //en
			   ( start_frame == 77705  && duration == 1950 ) ||     //de
			   ( start_frame == 73757  && duration == 1951 ) ||     //it 
			   ( start_frame == 75747  && duration == 1919 ) ||     //es 
			   //animation début niveau 13
			   ( start_frame == 79694  && duration == 2023 ) ||     //fr
			   ( start_frame == 81756  && duration == 1879 ) ||     //en
			   ( start_frame == 87614  && duration == 1945 ) ||     //de
			   ( start_frame == 83674  && duration == 1913 ) ||     //it  
			   ( start_frame == 85626  && duration == 1949 ) ||     //es  
			   //animation début niveau 16
		       ( start_frame == 89598  && duration == 1640 ) ||     //fr
			   ( start_frame == 91277  && duration == 1574 ) ||     //en
			   ( start_frame == 96134  && duration == 1515 ) ||     //de 
			   ( start_frame == 92890  && duration == 1487 ) ||     //it    
			   ( start_frame == 94416  && duration == 1679 ) ||     //es  
			   //animation début niveau 19
		       ( start_frame == 97688  && duration == 1497 ) ||     //fr
			   ( start_frame == 99224  && duration == 1348 ) ||     //en
			   ( start_frame == 103678 && duration == 1465 ) ||     //de 
			   ( start_frame == 100611 && duration == 1440 ) ||     //it   
			   ( start_frame == 102090 && duration == 1549 ) ||     //es  
			   //animation début niveau 22
			   ( start_frame == 105182 && duration == 1899 ) ||     //fr
			   ( start_frame == 113168 && duration == 2030 ) ||     //de 
			   ( start_frame == 108982 && duration == 2045 ) ||     //it  
			   ( start_frame == 111066 && duration == 2063 ) ||     //es  
			   ( start_frame == 107120 && duration == 1823 )        //en
			  ) )    			
		{
			if( !bLvLLoaded )
			{
				bLvLLoaded = true;
				[[NSNotificationCenter defaultCenter] postNotificationName:@"lvlLoadedNotif" object:nil];
			}
		}
		else
		{
			if( start_frame == 51813  && duration == 9766 )
			{
				[[NSNotificationCenter defaultCenter] postNotificationName:@"loadingOffAnimBeginningNotif" object:nil];
			}
			else if( start_frame != 138096 && duration != 9868 )
			{
				[[NSNotificationCenter defaultCenter] postNotificationName:@"loadingScreenOff" object:nil];
				bLvLLoaded = false;
			}
		}
		//---END@
		
		//printf("\nPLAY CD %d:%d:%d:%d\n",track,num_loops,start_frame,duration);
	}
}
