/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/scummvm/trunk/engines/gob/detection.cpp $
 * $Id: detection.cpp 46423 2009-12-19 23:33:48Z strangerke $
 *
 */

#include "base/plugins.h"
#include "engines/advancedDetector.h"

#include "igob/gob.h"

extern int _GobLanguage;

namespace Gob {

struct GOBGameDescription {
	ADGameDescription desc;

	GameType gameType;
	int32 features;
	const char *startStkBase;
	const char *startTotBase;
	uint32 demoIndex;
};

}

using namespace Common;

static const PlainGameDescriptor gobGames[] = {
	{"gob", "Gob engine game"},
	{"gob1", "Gobliiins"},
	{"gob1cd", "Gobliiins CD"},
	{"gob2", "Gobliins 2"},
	{"gob2cd", "Gobliins 2 CD"},
	{"gob3", "Goblins Quest 3"},
	{"gob3cd", "Goblins Quest 3 CD"},
	{0, 0}
};

static const ADObsoleteGameID obsoleteGameIDsTable[] = {
	{"gob1", "gob", kPlatformUnknown},
	{"gob2", "gob", kPlatformUnknown},
	{0, 0, kPlatformUnknown}
};

namespace Gob {

using Common::GUIO_NOSPEECH;
using Common::GUIO_NOSUBTITLES;
using Common::GUIO_NONE;

static const GOBGameDescription gameDescriptions[] = {
	{ // Supplied by Florian Zeitz on scummvm-devel
		{
			"gob1",
			"EGA",
			AD_ENTRY1("intro.stk", "c65e9cc8ba23a38456242e1f2b1caad4"),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesEGA,
		0, 0, 0
	},
	{
		{
			"gob1",
			"EGA",
			AD_ENTRY1("intro.stk", "f9233283a0be2464248d83e14b95f09c"),
			RU_RUS,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesEGA,
		0, 0, 0
	},
	{ // Supplied by Theruler76 in bug report #1201233
		{
			"gob1",
			"VGA",
			AD_ENTRY1("intro.stk", "26a9118c0770fa5ac93a9626761600b2"),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by raziel_ in bug report #1891864
		{
			"gob1",
			"VGA",
			AD_ENTRY1s("intro.stk", "e157cb59c6d330ca70d12ab0ef1dd12b", 288972),
			EN_GRB,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // CD 1.000 version.
		{
			"gob1cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "2fbf4b5b82bbaee87eb45d4404c28998"),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.000 version.
		{
			"gob1cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "2fbf4b5b82bbaee87eb45d4404c28998"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.000 version.
		{
			"gob1cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "2fbf4b5b82bbaee87eb45d4404c28998"),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.000 version.
		{
			"gob1cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "2fbf4b5b82bbaee87eb45d4404c28998"),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.000 version.
		{
			"gob1cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "2fbf4b5b82bbaee87eb45d4404c28998"),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.02 version. Multilingual
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "8bd873137b6831c896ee8ad217a6a398"),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.02 version. Multilingual
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "8bd873137b6831c896ee8ad217a6a398"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.02 version. Multilingual
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "8bd873137b6831c896ee8ad217a6a398"),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.02 version. Multilingual
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "8bd873137b6831c896ee8ad217a6a398"),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // CD 1.02 version. Multilingual
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "8bd873137b6831c896ee8ad217a6a398"),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "40d4a53818f4fce3f5997d02c3fafe73", 4049248),
			HU_HUN,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "40d4a53818f4fce3f5997d02c3fafe73", 4049248),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "40d4a53818f4fce3f5997d02c3fafe73", 4049248),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob1cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "40d4a53818f4fce3f5997d02c3fafe73", 4049248),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob1",
			"Demo",
			AD_ENTRY1("intro.stk", "972f22c6ff8144a6636423f0354ca549"),
			UNK_LANG,
			kPlatformAmiga,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{
		{
			"gob1",
			"Interactive Demo",
			AD_ENTRY1("intro.stk", "e72bd1e3828c7dec4c8a3e58c48bdfdb"),
			UNK_LANG,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{
		{
			"gob1",
			"Interactive Demo",
			AD_ENTRY1s("intro.stk", "a796096280d5efd48cf8e7dfbe426eb5", 193595),
			UNK_LANG,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2785958
		{
			"gob1",
			"Interactive Demo",
			AD_ENTRY1s("intro.stk", "35a098571af9a03c04e2303aec7c9249", 116582),
			FR_FRA,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by raina in the forums
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "6d837c6380d8f4d984c9f6cc0026df4f", 192712),
			EN_ANY,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by paul66 in bug report #1652352
		{
			"gob1",
			"",
			AD_ENTRY1("intro.stk", "00a42a7d2d22e6b6ab1b8c673c4ed267"),
			EN_ANY,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by paul66 in bug report #1652352
		{
			"gob1",
			"",
			AD_ENTRY1("intro.stk", "00a42a7d2d22e6b6ab1b8c673c4ed267"),
			DE_DEU,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by paul66 in bug report #1652352
		{
			"gob1",
			"",
			AD_ENTRY1("intro.stk", "00a42a7d2d22e6b6ab1b8c673c4ed267"),
			FR_FRA,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by paul66 in bug report #1652352
		{
			"gob1",
			"",
			AD_ENTRY1("intro.stk", "00a42a7d2d22e6b6ab1b8c673c4ed267"),
			IT_ITA,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by paul66 in bug report #1652352
		{
			"gob1",
			"",
			AD_ENTRY1("intro.stk", "00a42a7d2d22e6b6ab1b8c673c4ed267"),
			ES_ESP,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by Hkz on #scummvm
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "f5f028ee39c456fa51fa63b606583918", 313472},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by Hkz on #scummvm
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "f5f028ee39c456fa51fa63b606583918", 313472},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			IT_ITA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by Hkz on #scummvm
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "f5f028ee39c456fa51fa63b606583918", 313472},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			EN_GRB,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by Hkz on #scummvm
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "f5f028ee39c456fa51fa63b606583918", 313472},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			DE_DEU,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by Hkz on #scummvm
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "f5f028ee39c456fa51fa63b606583918", 313472},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			ES_ESP,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "e157cb59c6d330ca70d12ab0ef1dd12b", 288972},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			EN_GRB,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "e157cb59c6d330ca70d12ab0ef1dd12b", 288972},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "e157cb59c6d330ca70d12ab0ef1dd12b", 288972},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			ES_ESP,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "e157cb59c6d330ca70d12ab0ef1dd12b", 288972},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			IT_ITA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob1",
			"",
			{
				{"intro.stk", 0, "e157cb59c6d330ca70d12ab0ef1dd12b", 288972},
				{"musmac1.mid", 0, "4f66903b33df8a20edd4c748809c0b56", 8161},
				{0, 0, 0, 0}
			},
			DE_DEU,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "f5f028ee39c456fa51fa63b606583918", 313472),
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "f5f028ee39c456fa51fa63b606583918", 313472),
			EN_GRB,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "f5f028ee39c456fa51fa63b606583918", 313472),
			DE_DEU,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "f5f028ee39c456fa51fa63b606583918", 313472),
			IT_ITA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "f5f028ee39c456fa51fa63b606583918", 313472),
			ES_ESP,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob1",
			"",
			AD_ENTRY1s("intro.stk", "0e022d3f2481b39e9175d37b2c6ad4c6", 2390121),
			FR_FRA,
			kPlatformCDi,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesAdlib,
		0, "AVT003.TOT", 0
	},
	{ // Supplied by fac76 in bug report #1883808
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "eebf2810122cfd17399260cd1468e994", 554014),
			EN_ANY,
			kPlatformAmiga,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesNone,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "d28b9e9b41f31acfa58dcd12406c7b2c"),
			DE_DEU,
			kPlatformAmiga,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2602057
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "686c88f7302a80b744aae9f8413e853d"),
			IT_ITA,
			kPlatformAmiga,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by bgk in bug report #1706861
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "4b13c02d1069b86bcfec80f4e474b98b", 554680),
			FR_FRA,
			kPlatformAtariST,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by fac76 in bug report #1673397
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "b45b984ee8017efd6ea965b9becd4d66", 828443},
				{"musmac1.mid", 0, "7f96f491448c7a001b32df89cf8d2af2", 1658},
				{0, 0, 0, 0}
			},
			UNK_LANG,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by koalet in bug report #2478585
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "a13ecb4f6d8fd881ebbcc02e45cb5475", 837275},
				{"musmac1.mid", 0, "7f96f491448c7a001b32df89cf8d2af2", 1658},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "b45b984ee8017efd6ea965b9becd4d66"),
			EN_GRB,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "dedb5d31d8c8050a8cf77abedcc53dae"),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by raziel_ in bug report #1891867
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "25a99827cd59751a80bed9620fb677a0", 893302),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "a13ecb4f6d8fd881ebbcc02e45cb5475", 837275),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by blackwhiteeagle in bug report #1605235
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "3e4e7db0d201587dd2df4003b2993ef6"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "a13892cdf4badda85a6f6fb47603a128"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2602017
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "c47faf1d406504e6ffe63243610bb1f4"),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			AD_ENTRY1("intro.stk", "cd3e1df8b273636ee32e34b7064f50e8"),
			RU_RUS,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by arcepi in bug report #1659884
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "5f53c56e3aa2f1e76c2e4f0caa15887f", 829232),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "9de5fbb41cf97182109e5fecc9d90347"),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob2cd",
			"v2.01",
			AD_ENTRY1("intro.stk", "24a6b32757752ccb1917ce92fd7c2a04"),
			EN_ANY,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob2cd",
			"v2.01",
			AD_ENTRY1("intro.stk", "24a6b32757752ccb1917ce92fd7c2a04"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob2cd",
			"v2.01",
			AD_ENTRY1("intro.stk", "24a6b32757752ccb1917ce92fd7c2a04"),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob2cd",
			"v2.01",
			AD_ENTRY1("intro.stk", "24a6b32757752ccb1917ce92fd7c2a04"),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob2cd",
			"v2.01",
			AD_ENTRY1("intro.stk", "24a6b32757752ccb1917ce92fd7c2a04"),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob2cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "5ba85a4769a1ab03a283dd694588d526", 5006236),
			HU_HUN,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob2cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "5ba85a4769a1ab03a283dd694588d526", 5006236),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob2cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "5ba85a4769a1ab03a283dd694588d526", 5006236),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob2cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "5ba85a4769a1ab03a283dd694588d526", 5006236),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob2cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "5ba85a4769a1ab03a283dd694588d526", 5006236),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob2",
			"Non-Interactive Demo",
			AD_ENTRY1("intro.stk", "8b1c98ff2ab2e14f47a1b891e9b92217"),
			UNK_LANG,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, "usa.tot", 0
	},
	{
		{
			"gob2",
			"Interactive Demo",
			AD_ENTRY1("intro.stk", "cf1c95b2939bd8ff58a25c756cb6125e"),
			UNK_LANG,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"Interactive Demo",
			AD_ENTRY1("intro.stk", "4b278c2678ea01383fd5ca114d947eea"),
			UNK_LANG,
			kPlatformAmiga,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesNone,
		0, 0, 0
	},
	{ // Supplied by polluks in bug report #1895126
		{
			"gob2",
			"Interactive Demo",
			AD_ENTRY1s("intro.stk", "9fa85aea959fa8c582085855fbd99346", 553063),
			UNK_LANG,
			kPlatformAmiga,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesNone,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "285d7340f98ebad65d465585da12910b", 837286},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "25a99827cd59751a80bed9620fb677a0", 893302},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			EN_USA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "25a99827cd59751a80bed9620fb677a0", 893302},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "25a99827cd59751a80bed9620fb677a0", 893302},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			DE_DEU,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "6efac0a14c0de4d57dde8592456c8acf", 845172},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			EN_USA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob2",
			"",
			{
				{"intro.stk", 0, "6efac0a14c0de4d57dde8592456c8acf", 845172},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in french ADI 2 Francais-Maths CM1
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "24489330a1d67ff978211f574822a5a6", 883756),
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob2",
			"",
			AD_ENTRY1s("intro.stk", "285d7340f98ebad65d465585da12910b", 837286),
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1s("intro.stk", "32b0f57f5ae79a9ae97e8011df38af42", 157084),
			EN_GRB,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1s("intro.stk", "904fc32032295baa3efb3a41f17db611", 178582),
			HB_ISR,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by raziel_ in bug report #1891869
		{
			"gob3",
			"",
			AD_ENTRY1s("intro.stk", "16b014bf32dbd6ab4c5163c44f56fed1", 445104),
			EN_GRB,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "16b014bf32dbd6ab4c5163c44f56fed1", 445104},
				{"musmac1.mid", 0, "948c546cad3a9de5bff3fe4107c82bf1", 6404},
				{0, 0, 0, 0}
			},
			DE_DEU,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "16b014bf32dbd6ab4c5163c44f56fed1", 445104},
				{"musmac1.mid", 0, "948c546cad3a9de5bff3fe4107c82bf1", 6404},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "16b014bf32dbd6ab4c5163c44f56fed1", 445104},
				{"musmac1.mid", 0, "948c546cad3a9de5bff3fe4107c82bf1", 6404},
				{0, 0, 0, 0}
			},
			EN_GRB,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by fac76 in bug report #1742716
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "32b0f57f5ae79a9ae97e8011df38af42", 157084},
				{"musmac1.mid", 0, "834e55205b710d0af5f14a6f2320dd8e", 8661},
				{0, 0, 0, 0}
			},
			EN_GRB,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "1e2f64ec8dfa89f42ee49936a27e66e7"),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by paul66 in bug report #1652352
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "f6d225b25a180606fa5dbe6405c97380"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "e42a4f2337d6549487a80864d7826972"),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by Paranoimia on #scummvm
		{
			"gob3",
			"",
			AD_ENTRY1s("intro.stk", "fe8144daece35538085adb59c2d29613", 159402),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "4e3af248a48a2321364736afab868527"),
			RU_RUS,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "8d28ce1591b0e9cc79bf41cad0fc4c9c"),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Supplied by SiRoCs in bug report #2098621
		{
			"gob3",
			"",
			AD_ENTRY1s("intro.stk", "d3b72938fbbc8159198088811f9e6d19", 160382),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "bd679eafde2084d8011f247e51b5a805"),
			EN_GRB,
			kPlatformAmiga,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesNone,
		0, "menu.tot", 0
	},
	{
		{
			"gob3",
			"",
			AD_ENTRY1("intro.stk", "bd679eafde2084d8011f247e51b5a805"),
			DE_DEU,
			kPlatformAmiga,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesNone,
		0, "menu.tot", 0
	},
	{
		{
			"gob3cd",
			"v1.000",
			AD_ENTRY1("intro.stk", "6f2c226c62dd7ab0ab6f850e89d3fc47"),
			EN_USA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by paul66 and noizert in bug reports #1652352 and #1691230
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "c3e9132ea9dc0fb866b6d60dcda10261"),
			EN_ANY,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by paul66 and noizert in bug reports #1652352 and #1691230
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "c3e9132ea9dc0fb866b6d60dcda10261"),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by paul66 and noizert in bug reports #1652352 and #1691230
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "c3e9132ea9dc0fb866b6d60dcda10261"),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by paul66 and noizert in bug reports #1652352 and #1691230
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "c3e9132ea9dc0fb866b6d60dcda10261"),
			IT_ITA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by paul66 and noizert in bug reports #1652352 and #1691230
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1("intro.stk", "c3e9132ea9dc0fb866b6d60dcda10261"),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "bfd7d4c6fedeb2cfcc8baa4d5ddb1f74", 616220),
			HU_HUN,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "bfd7d4c6fedeb2cfcc8baa4d5ddb1f74", 616220),
			FR_FRA,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "bfd7d4c6fedeb2cfcc8baa4d5ddb1f74", 616220),
			DE_DEU,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{ // Supplied by goodoldgeorg in bug report #2810082
		{
			"gob3cd",
			"v1.02",
			AD_ENTRY1s("intro.stk", "bfd7d4c6fedeb2cfcc8baa4d5ddb1f74", 616220),
			ES_ESP,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	},
	{
		{
			"gob3",
			"Interactive Demo",
			AD_ENTRY1("intro.stk", "7aebd94e49c2c5c518c9e7b74f25de9d"),
			FR_FRA,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"Interactive Demo 2",
			AD_ENTRY1("intro.stk", "e5dcbc9f6658ebb1e8fe26bc4da0806d"),
			FR_FRA,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"Non-interactive Demo",
			AD_ENTRY1("intro.stk", "b9b898fccebe02b69c086052d5024a55"),
			UNK_LANG,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"Interactive Demo 3",
			AD_ENTRY1s("intro.stk", "9e20ad7b471b01f84db526da34eaf0a2", 395561),
			EN_ANY,
			kPlatformPC,
			ADGF_DEMO,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "edd7403e5dc2a14459d2665a4c17714d", 209534},
				{"musmac1.mid", 0, "948c546cad3a9de5bff3fe4107c82bf1", 6404},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "428e2de130cf3b303c938924539dc50d", 324420},
				{"musmac1.mid", 0, "948c546cad3a9de5bff3fe4107c82bf1", 6404},
				{0, 0, 0, 0}
			},
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{
		{
			"gob3",
			"",
			{
				{"intro.stk", 0, "428e2de130cf3b303c938924539dc50d", 324420},
				{"musmac1.mid", 0, "948c546cad3a9de5bff3fe4107c82bf1", 6404},
				{0, 0, 0, 0}
			},
			EN_ANY,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ // Found in Found in french ADI 2.5 Anglais Multimedia 5e
		{
			"gob3",
			"",
			AD_ENTRY1s("intro.stk", "edd7403e5dc2a14459d2665a4c17714d", 209534),
			FR_FRA,
			kPlatformWindows,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ AD_TABLE_END_MARKER, kGameTypeNone, kFeaturesNone, 0, 0, 0}
};

static const GOBGameDescription fallbackDescs[] = {
	{ //0
		{
			"gob1",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesNone,
		0, 0, 0
	},
	{ //1
		{
			"gob1cd",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob1,
		kFeaturesCD,
		0, 0, 0
	},
	{ //2
		{
			"gob2",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ //3
		{
			"gob2mac",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformMacintosh,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ //4
		{
			"gob2cd",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob2,
		kFeaturesCD,
		0, 0, 0
	},
	{ //6
		{
			"gob3",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesAdlib,
		0, 0, 0
	},
	{ //7
		{
			"gob3cd",
			"unknown",
			AD_ENTRY1(0, 0),
			UNK_LANG,
			kPlatformPC,
			ADGF_NO_FLAGS,
			GUIO_NOSUBTITLES | GUIO_NOSPEECH
		},
		kGameTypeGob3,
		kFeaturesCD,
		0, 0, 0
	}
};

static const ADFileBasedFallback fileBased[] = {
	{ &fallbackDescs[ 0], { "intro.stk", "disk1.stk", "disk2.stk", "disk3.stk", "disk4.stk", 0 } },
	{ &fallbackDescs[ 1], { "intro.stk", "gob.lic", 0 } },
	{ &fallbackDescs[ 2], { "intro.stk", 0 } },
	{ &fallbackDescs[ 2], { "intro.stk", "disk2.stk", "disk3.stk", 0 } },
	{ &fallbackDescs[ 3], { "intro.stk", "disk2.stk", "disk3.stk", "musmac1.mid", 0 } },
	{ &fallbackDescs[ 4], { "intro.stk", "gobnew.lic", 0 } },
	{ &fallbackDescs[ 5], { "intro.stk", "scaa.imd", "scba.imd", "scbf.imd", 0 } },
	{ &fallbackDescs[ 6], { "intro.stk", "imd.itk", 0 } },
	{ &fallbackDescs[ 7], { "intro.stk", "mus_gob3.lic", 0 } },
	{ &fallbackDescs[ 8], { "intro.stk", "woodruff.itk", 0 } },
	{ &fallbackDescs[ 9], { "intro.stk", "commun1.itk", 0 } },
	{ &fallbackDescs[10], { "intro.stk", "commun1.itk", "musmac1.mid", 0 } },
	{ &fallbackDescs[11], { "intro.stk", "commun1.itk", "lost.lic", 0 } },
	{ &fallbackDescs[12], { "intro.stk", "cd1.itk", "objet1.itk", 0 } },
	{ &fallbackDescs[13], { "playtoon.stk", "archi.stk", 0 } },
	{ &fallbackDescs[14], { "playtoon.stk", "spirou.stk", 0 } },
	{ &fallbackDescs[15], { "playtoon.stk", "chato.stk", 0 } },
	{ &fallbackDescs[16], { "playtoon.stk", "manda.stk", 0 } },
	{ &fallbackDescs[17], { "playtoon.stk", "wakan.stk", 0 } },
	{ &fallbackDescs[18], { "playtoon.stk", "dan.itk" } },
	{ &fallbackDescs[19], { "intro.stk", "bambou.itk", 0 } },
	{ &fallbackDescs[20], { "disk0.stk", "disk1.stk", "disk2.stk", "disk3.stk", 0 } },
	{ &fallbackDescs[21], { "disk1.stk", "disk2.stk", "disk3.stk", 0 } },
	{ &fallbackDescs[22], { "adi2.stk", 0 } },
	{ &fallbackDescs[23], { "adif41.stk", "adim41.stk", 0 } },
	{ &fallbackDescs[24], { "coktelplayer.scn", 0 } },
	{ 0, { 0 } }
};

}

static const ADParams detectionParams = {
	// Pointer to ADGameDescription or its superset structure
	(const byte *)Gob::gameDescriptions,
	// Size of that superset structure
	sizeof(Gob::GOBGameDescription),
	// Number of bytes to compute MD5 sum for
	5000,
	// List of all engine targets
	gobGames,
	// Structure for autoupgrading obsolete targets
	obsoleteGameIDsTable,
	// Name of single gameid (optional)
	"gob",
	// List of files for file-based fallback detection (optional)
	Gob::fileBased,
	// Flags
	0,
	// Additional GUI options (for every game}
	Common::GUIO_NOLAUNCHLOAD
};

class GobMetaEngine : public AdvancedMetaEngine {
public:
	GobMetaEngine() : AdvancedMetaEngine(detectionParams) {}

	virtual const char *getName() const {
		return "Gob Engine";
	}

	virtual const char *getOriginalCopyright() const {
		return "Goblins Games (C) Coktel Vision";
	}

	virtual bool hasFeature(MetaEngineFeature f) const;
	virtual bool createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const;
};

bool GobMetaEngine::hasFeature(MetaEngineFeature f) const {
	return false;
}

bool Gob::GobEngine::hasFeature(EngineFeature f) const {
	return
		(f == kSupportsRTL);
}
bool GobMetaEngine::createInstance(OSystem *syst, Engine **engine, const ADGameDescription *desc) const {
	const Gob::GOBGameDescription *gd = (const Gob::GOBGameDescription *)desc;
	if (gd) {
		*engine = new Gob::GobEngine(syst);
		((Gob::GobEngine *)*engine)->initGame(gd);
	}
	return gd != 0;
}

#if PLUGIN_ENABLED_DYNAMIC(GOB)
	REGISTER_PLUGIN_DYNAMIC(GOB, PLUGIN_TYPE_ENGINE, GobMetaEngine);
#else
	REGISTER_PLUGIN_STATIC(GOB, PLUGIN_TYPE_ENGINE, GobMetaEngine);
#endif

namespace Gob {

void GobEngine::initGame(const GOBGameDescription *gd)
{
	if (gd->startTotBase == 0)
		_startTot = "intro.tot";
	else
		_startTot = gd->startTotBase;

	if (gd->startStkBase == 0)
		_startStk = "intro.stk";
	else
		_startStk = gd->startStkBase;

	_demoIndex = gd->demoIndex;

	_gameType = gd->gameType;
	_features = gd->features;
	if( _GobLanguage == 0 )
		_language = EN_USA;
	else if( _GobLanguage == 1 )
		_language = FR_FRA;//gd->desc.language; //6EN_USA 7FR_FRA 8DE_DEU 12IT_ITA 19ES_ESP
	_platform = gd->desc.platform;
}
	
} // End of namespace Gob
